#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Fenrir TTY screen reader
# By Chrys, Storm Dragon, and contributers.

from fenrirscreenreader.core import debug
import importlib
import _thread
import pyperclip
import os

class command():
    def __init__(self):
        pass
    def initialize(self, environment, scriptPath=''):
        self.env = environment
        self.scriptPath = scriptPath
    def shutdown(self):
        pass
    def getDescription(self):
        return _("imports the graphical clipboard to Fenrir's clipboard")
    def run(self):                       
       _thread.start_new_thread(self._threadRun , ())
    def _threadRun(self):
        try:
            # Remember original display environment variable if it exists
            originalDisplay = os.environ.get('DISPLAY', '')
            clipboardContent = None
            
            # Try different display options
            for i in range(10):
                display = f":{i}"
                try:
                    # Set display environment variable
                    os.environ['DISPLAY'] = display
                    # Attempt to get clipboard content
                    importlib.reload(pyperclip) # Weird workaround for some distros
                    clipboardContent = pyperclip.paste()
                    # If we get here without exception, we found a working display
                    if clipboardContent:
                        break
                except Exception:
                    # Failed for this display, try next one
                    continue
            
            # Restore original display setting
            if originalDisplay:
                os.environ['DISPLAY'] = originalDisplay
            else:
                os.environ.pop('DISPLAY', None)
            
            # Process the clipboard content if we found any
            if clipboardContent and isinstance(clipboardContent, str):
                self.env['runtime']['memoryManager'].addValueToFirstIndex('clipboardHistory', clipboardContent)
                self.env['runtime']['outputManager'].presentText('Import to Clipboard', soundIcon='CopyToClipboard', interrupt=True)
                self.env['runtime']['outputManager'].presentText(clipboardContent, soundIcon='', interrupt=False)
            else:
                self.env['runtime']['outputManager'].presentText('No text found in clipboard or no accessible display', interrupt=True)
        except Exception as e:
            self.env['runtime']['outputManager'].presentText(str(e), soundIcon='', interrupt=False)
        
    def setCallback(self, callback):
        pass
